@@ -1,7 +1,7 @@
 package config
 
 import (
-	"io/ioutil"
+	"os"
 	"path/filepath"
 	"strings"
 	"testing"
@@ -21,12 +21,12 @@ func Test_migration(t *testing.T) {
 			_, cfgDir, cleanup := setupEnv(t)
 			defer cleanup()
 
-			b, err := ioutil.ReadFile(filepath.Join(oldCWD, "testdata", toFileName(oldVer)))
+			b, err := os.ReadFile(filepath.Join(oldCWD, "testdata", toFileName(oldVer)))
 			if err != nil {
 				t.Fatalf("failed to read a config file, but got '%s'", err)
 			}
 
-			err = ioutil.WriteFile(filepath.Join(cfgDir, "config.toml"), b, 0600)
+			err = os.WriteFile(filepath.Join(cfgDir, "config.toml"), b, 0600)
 			if err != nil {
 				t.Fatalf("failed to copy a config file to a temp config dir, but got '%s'", err)
 			}
